@@ -18,8 +18,9 @@
         <translation>MX Opstartsreparation</translation>
     </message>
     <message>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation type="vanished">MX Opstartsreparation er et redskab som kan bruges til at geninstallere GRUB-opstartsindlæser på MBR&apos;en (Master Boot Record) eller rodpartitionen. Den giver mulighed for at rekonstruere GRUB-konfigurationsfilen og at sikkerhedskopiere og gendanne MBR eller PBR.</translation>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation>MX Opstartsreparation er et redskab som kan bruges til at geninstallere GRUB-opstartsindlæser på ESP&apos;en (EFI System Partition), MBR&apos;en (Master Boot Record) eller rodpartitionen. Den giver mulighed for at rekonstruere GRUB-konfigurationsfilen og at sikkerhedskopiere og gendanne MBR eller PBR (rod).</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
@@ -31,19 +32,10 @@
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Sikkerhedskopiér MBR eller PBR (kun forældet opstart)</translation>
     </message>
-    <message>
-        <source>Reinstall GRUB bootloader</source>
-        <translation type="vanished">Geninstaller GRUB-opstartsindlæser</translation>
-    </message>
-    <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation type="unfinished"></translation>
+        <translation>Geninstaller GRUB-opstartsindlæser på ESP, MBR eller PBR (rod)</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="96"/>
