@@ -18,8 +18,9 @@
         <translation>MX Reparador de Inicialização</translation>
     </message>
     <message>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation type="vanished">O MX Reparador de Inicialização é um utilitário que pode ser usado para reinstalar o gerenciador de inicialização GRUB no MBR (Master Boot Record) ou na partição root. Oferece as opções de reconstrução do arquivo de configuração do GRUB e de fazer uma cópia e restaurar o MBR ou o PBR.</translation>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
@@ -31,19 +32,10 @@
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
     </message>
-    <message>
-        <source>Reinstall GRUB bootloader</source>
-        <translation type="vanished">Reinstalar o gerenciador de iniciação GRUB</translation>
-    </message>
-    <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation type="unfinished"></translation>
+        <translation>Reinstalar o gerenciador de iniciação GRUB em ESP, MBR ou PBR (root)</translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="96"/>
