@@ -17,6 +17,11 @@
         <source>MX Boot Repair</source>
         <translation>MX Reparare Boot</translation>
     </message>
+    <message>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
         <source>What would you like to do?</source>
@@ -27,15 +32,6 @@
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Reinstall GRUB bootloader</source>
-        <translation type="vanished">Reinstalare GRUB</translation>
-    </message>
-    <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
