@@ -18,8 +18,9 @@
         <translation>MX 開機修復</translation>
     </message>
     <message>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
-        <translation type="vanished">MX 開機修復工具可以把 GRUB 開機管理程式重新安裝到 MBR（主要開機記錄區）或者根目錄的磁碟區。它亦可重建 GRUB 設定檔，以及備份、修復 MBR 或 PBR。</translation>
+        <location filename="../mxbootrepair.ui" line="39"/>
+        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mxbootrepair.ui" line="58"/>
@@ -31,15 +32,6 @@
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>備份 MBR 或 PBR（僅限舊式開機）</translation>
     </message>
-    <message>
-        <source>Reinstall GRUB bootloader</source>
-        <translation type="vanished">重新安裝 GRUB 開機管理程式</translation>
-    </message>
-    <message>
-        <location filename="../mxbootrepair.ui" line="39"/>
-        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
